%global udev_rules 70-avrdude_usbprog.rules

%bcond_without docs

Name:           avrdude
Version:        7.2
Release:    1%{?dist}
Summary:        Software for programming Atmel AVR Microcontroller

License:        GPL-2.0-or-later AND GPL-3.0-only AND (WTFPL OR MIT)
URL:            https://github.com/avrdudes/avrdude


Source0:        %{name}-%{version}-filtered.tar.xz
Source10:       filter-tarball
Source11:       file-licensing

Source1:        avrdude.udev

Source2:        README

Patch1:         avrdude-udev-no-blanket-access.patch

Patch2:         avrdude-7.2-detect-readline.patch

Patch0:          avrdude-7.2-relocate-avrdude-conf.patch

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  elfutils-libelf-devel
BuildRequires:  hidapi-devel
BuildRequires:  libhid-devel
BuildRequires:  readline-devel
BuildRequires:  ncurses-devel
BuildRequires:  libftdi-devel
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(libusb-1.0)
%if %{with docs}
BuildRequires:  texi2html
BuildRequires:  texinfo
BuildRequires:  texinfo-tex
%endif
BuildRequires:  make



%description
AVRDUDE is a program for programming Atmel's AVR CPU's. It can program the
Flash and EEPROM, and where supported by the serial programming protocol, it
can program fuse and lock bits. AVRDUDE also supplies a direct instruction
mode allowing one to issue any programming instruction to the AVR chip
regardless of whether AVRDUDE implements that specific feature of a
particular chip.


%prep
%setup -q -n %{name}-%{version}
cp -p %{SOURCE1} avrdude.udev
%autopatch -v -p1
if test -d atmel-docs; then
  echo "Directory 'atmel-docs' still exists, aborting."
  exit 2
fi


%build
%cmake \
       -D CMAKE_INSTALL_SYSCONFDIR:PATH=%{_sysconfdir} \
       -D CMAKE_BUILD_TYPE=build_type=RelWithDebInfo \
%if %{with docs}
       -D BUILD_DOC:BOOL=ON \
%else
       -D BUILD_DOC:BOOL=OFF \
%endif
       -D HAVE_LINUXSPI:BOOL=ON \
       -D HAVE_PARPORT:BOOL=ON \
       -D FETCHCONTENT_FULLY_DISCONNECTED:BOOL=ON \
       -D FETCHCONTENT_QUIET:BOOL=OFF \
       -D BUILD_SHARED_LIBS:BOOL=NO \
       -D USE_STATIC_LIBS:BOOL=YES
%cmake_build


%install
%cmake_install
rm -f %{buildroot}%{_includedir}/libavrdude.h
rm -f %{buildroot}%{_infodir}/dir
rm -f %{buildroot}%{_libdir}/libavrdude.a
rm -f %{buildroot}%{_libdir}/libavrdude.so
rm -f %{buildroot}%{_libdir}/libavrdude.so.1
rm -f %{buildroot}%{_libdir}/libavrdude.so.1.0.0
rm -f %{buildroot}%{_pkgdocdir}/avrdude.dvi
rm -f %{buildroot}%{_pkgdocdir}/avrdude.ps
install -d -m 755 %{buildroot}%{_udevrulesdir}
install -p -m 644 avrdude.udev %{buildroot}%{_udevrulesdir}/%{udev_rules}
install -d -m 755 %{buildroot}%{_pkgdocdir}
install -p -m 644 %{SOURCE2} %{buildroot}%{_pkgdocdir}/README
install -p -m 644 -t %{buildroot}%{_pkgdocdir} AUTHORS NEWS README.md


%check
%ctest


%files
%license COPYING
%doc %{_pkgdocdir}/AUTHORS
%doc %{_pkgdocdir}/NEWS
%doc %{_pkgdocdir}/README.md
%doc %{_pkgdocdir}/README
%if %{with docs}
%doc %{_pkgdocdir}/avrdude-html/
%doc %{_pkgdocdir}/avrdude.pdf
%endif
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/avrdude.conf
%{_udevrulesdir}/%{udev_rules}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%if %{with docs}
%{_infodir}/%{name}.info*
%endif


%changelog
* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.2-1
- initial build
